==> car-4.0.0.tgz: package/cjs/node-test/test-indexer.js <==
'use strict';

var indexer = require('../lib/indexer.js');
var common = require('./common.js');
var verifyStoreReader = require('./verify-store-reader.js');

describe('CarIndexer fromBytes()', () => {
  it('complete', async () => {
    const indexer$1 = await indexer.CarIndexer.fromBytes(common.goCarBytes);
    await verifyStoreReader.verifyRoots(indexer$1);
    common.assert.strictEqual(indexer$1.version, 1);
    const indexData = [];
    for await (const index of indexer$1) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarIndex);
  });
  it('v2 complete', async () => {
    const indexer$1 = await indexer.CarIndexer.fromBytes(common.goCarV2Bytes);
    const roots = await indexer$1.getRoots();
    common.assert.strictEqual(roots.length, 1);
    common.assert(common.goCarV2Roots[0].equals(roots[0]));
    common.assert.strictEqual(indexer$1.version, 2);
    const indexData = [];
    for await (const index of indexer$1) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarV2Index);
  });
  it('bad argument', async () => {
    for (const arg of [
        true,
        false,
        null,
        undefined,
        'string',
        100,
        { obj: 'nope' }
      ]) {
      await common.assert.isRejected(indexer.CarIndexer.fromBytes(arg));
    }
  });
});
describe('CarIndexer fromIterable()', () => {
  async function verifyIndexer(indexer) {
    await verifyStoreReader.verifyRoots(indexer);
    common.assert.strictEqual(indexer.version, 1);
    const indexData = [];
    for await (const index of indexer) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarIndex);
  }
  it('complete (single chunk)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, common.goCarBytes.length));
    return verifyIndexer(indexer$1);
  });
  it('complete (101-byte chunks)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, 101));
    return verifyIndexer(indexer$1);
  });
  it('complete (32-byte chunks)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, 32));
    return verifyIndexer(indexer$1);
  });
  it('bad argument', async () => {
    for (const arg of [
        new Uint8Array(0),
        true,
        false,
        null,
        undefined,
        'string',
        100,
        { obj: 'nope' }
      ]) {
      await common.assert.isRejected(indexer.CarIndexer.fromIterable(arg));
    }
  });
});

==> car-4.1.6.tgz: package/cjs/node-test/test-indexer.js <==
'use strict';

var indexer = require('../lib/indexer.js');
var common = require('./common.js');
var verifyStoreReader = require('./verify-store-reader.js');

describe('CarIndexer fromBytes()', () => {
  it('complete', async () => {
    const indexer$1 = await indexer.CarIndexer.fromBytes(common.goCarBytes);
    await verifyStoreReader.verifyRoots(indexer$1);
    common.assert.strictEqual(indexer$1.version, 1);
    const indexData = [];
    for await (const index of indexer$1) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarIndex);
  });
  it('v2 complete', async () => {
    const indexer$1 = await indexer.CarIndexer.fromBytes(common.goCarV2Bytes);
    const roots = await indexer$1.getRoots();
    common.assert.strictEqual(roots.length, 1);
    common.assert.ok(common.goCarV2Roots[0].equals(roots[0]));
    common.assert.strictEqual(indexer$1.version, 2);
    const indexData = [];
    for await (const index of indexer$1) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarV2Index);
  });
  it('bad argument', async () => {
    for (const arg of [
        true,
        false,
        null,
        undefined,
        'string',
        100,
        { obj: 'nope' }
      ]) {
      await common.assert.isRejected(indexer.CarIndexer.fromBytes(arg));
    }
  });
});
describe('CarIndexer fromIterable()', () => {
  async function verifyIndexer(indexer) {
    await verifyStoreReader.verifyRoots(indexer);
    common.assert.strictEqual(indexer.version, 1);
    const indexData = [];
    for await (const index of indexer) {
      indexData.push(index);
    }
    common.assert.deepStrictEqual(indexData, common.goCarIndex);
  }
  it('complete (single chunk)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, common.goCarBytes.length));
    return verifyIndexer(indexer$1);
  });
  it('complete (101-byte chunks)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, 101));
    return verifyIndexer(indexer$1);
  });
  it('complete (32-byte chunks)', async () => {
    const indexer$1 = await indexer.CarIndexer.fromIterable(common.makeIterable(common.goCarBytes, 32));
    return verifyIndexer(indexer$1);
  });
  it('bad argument', async () => {
    for (const arg of [
        new Uint8Array(0),
        true,
        false,
        null,
        undefined,
        'string',
        100,
        { obj: 'nope' }
      ]) {
      await common.assert.isRejected(indexer.CarIndexer.fromIterable(arg));
    }
  });
});
